---
title: <span class="badge object-type-scalar"></span> ScientificNotation
---
# <span class="badge object-type-scalar"></span> ScientificNotation

## Definition

```python
ScientificNotation: typing.Literal["sci"] = "sci"
```
